#!/bin/env python3

import argparse
import os

import numpy as np
import cv2
import open3d as o3d

from utils import load_lut
from save_pclouds import get_points_in_cam_space

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Visualize pgm file')
    parser.add_argument('path')

    print("Load a pgm file, print it, and render it")

    args = parser.parse_args()

    calib_file = os.path.join(os.path.dirname(args.path), '..', 'Depth Long Throw_lut.bin')

    img = cv2.imread(args.path, -1)
    height, width = img.shape

    lut = load_lut(calib_file)
    points = get_points_in_cam_space(img, lut)

    pcd = o3d.geometry.PointCloud()
    pcd.points = o3d.utility.Vector3dVector(points)

    o3d.visualization.draw_geometries([pcd])
